==> cdktf-provider-google-13.1.0-sources.jar: com/hashicorp/cdktf/providers/google/monitoring_alert_policy/MonitoringAlertPolicyAlertStrategyNotificationRateLimit.java <==
package com.hashicorp.cdktf.providers.google.monitoring_alert_policy;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-17T04:17:42.428Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.monitoringAlertPolicy.MonitoringAlertPolicyAlertStrategyNotificationRateLimit")
@software.amazon.jsii.Jsii.Proxy(MonitoringAlertPolicyAlertStrategyNotificationRateLimit.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface MonitoringAlertPolicyAlertStrategyNotificationRateLimit extends software.amazon.jsii.JsiiSerializable {

    /**
     * Not more than one notification per period.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/monitoring_alert_policy#period MonitoringAlertPolicy#period}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getPeriod() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link MonitoringAlertPolicyAlertStrategyNotificationRateLimit}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MonitoringAlertPolicyAlertStrategyNotificationRateLimit}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<MonitoringAlertPolicyAlertStrategyNotificationRateLimit> {
        java.lang.String period;

        /**
         * Sets the value of {@link MonitoringAlertPolicyAlertStrategyNotificationRateLimit#getPeriod}
         * @param period Not more than one notification per period.
         *               Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/monitoring_alert_policy#period MonitoringAlertPolicy#period}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder period(java.lang.String period) {
            this.period = period;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MonitoringAlertPolicyAlertStrategyNotificationRateLimit}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public MonitoringAlertPolicyAlertStrategyNotificationRateLimit build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MonitoringAlertPolicyAlertStrategyNotificationRateLimit}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MonitoringAlertPolicyAlertStrategyNotificationRateLimit {
        private final java.lang.String period;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.period = software.amazon.jsii.Kernel.get(this, "period", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.period = builder.period;
        }

        @Override
        public final java.lang.String getPeriod() {
            return this.period;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getPeriod() != null) {
                data.set("period", om.valueToTree(this.getPeriod()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.monitoringAlertPolicy.MonitoringAlertPolicyAlertStrategyNotificationRateLimit"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MonitoringAlertPolicyAlertStrategyNotificationRateLimit.Jsii$Proxy that = (MonitoringAlertPolicyAlertStrategyNotificationRateLimit.Jsii$Proxy) o;

            return this.period != null ? this.period.equals(that.period) : that.period == null;
        }

        @Override
        public final int hashCode() {
            int result = this.period != null ? this.period.hashCode() : 0;
            return result;
        }
    }
}

==> cdktf-provider-google-13.13.0-sources.jar: com/hashicorp/cdktf/providers/google/monitoring_alert_policy/MonitoringAlertPolicyAlertStrategyNotificationRateLimit.java <==
package com.hashicorp.cdktf.providers.google.monitoring_alert_policy;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.96.0 (build 921e240)", date = "2024-04-09T03:36:16.576Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.monitoringAlertPolicy.MonitoringAlertPolicyAlertStrategyNotificationRateLimit")
@software.amazon.jsii.Jsii.Proxy(MonitoringAlertPolicyAlertStrategyNotificationRateLimit.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface MonitoringAlertPolicyAlertStrategyNotificationRateLimit extends software.amazon.jsii.JsiiSerializable {

    /**
     * Not more than one notification per period.
     * <p>
     * A duration in seconds with up to nine fractional digits, terminated by 's'. Example "60.5s".
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/monitoring_alert_policy#period MonitoringAlertPolicy#period}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getPeriod() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link MonitoringAlertPolicyAlertStrategyNotificationRateLimit}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MonitoringAlertPolicyAlertStrategyNotificationRateLimit}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<MonitoringAlertPolicyAlertStrategyNotificationRateLimit> {
        java.lang.String period;

        /**
         * Sets the value of {@link MonitoringAlertPolicyAlertStrategyNotificationRateLimit#getPeriod}
         * @param period Not more than one notification per period.
         *               A duration in seconds with up to nine fractional digits, terminated by 's'. Example "60.5s".
         *               
         *               Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/monitoring_alert_policy#period MonitoringAlertPolicy#period}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder period(java.lang.String period) {
            this.period = period;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MonitoringAlertPolicyAlertStrategyNotificationRateLimit}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public MonitoringAlertPolicyAlertStrategyNotificationRateLimit build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MonitoringAlertPolicyAlertStrategyNotificationRateLimit}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MonitoringAlertPolicyAlertStrategyNotificationRateLimit {
        private final java.lang.String period;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.period = software.amazon.jsii.Kernel.get(this, "period", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.period = builder.period;
        }

        @Override
        public final java.lang.String getPeriod() {
            return this.period;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getPeriod() != null) {
                data.set("period", om.valueToTree(this.getPeriod()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.monitoringAlertPolicy.MonitoringAlertPolicyAlertStrategyNotificationRateLimit"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MonitoringAlertPolicyAlertStrategyNotificationRateLimit.Jsii$Proxy that = (MonitoringAlertPolicyAlertStrategyNotificationRateLimit.Jsii$Proxy) o;

            return this.period != null ? this.period.equals(that.period) : that.period == null;
        }

        @Override
        public final int hashCode() {
            int result = this.period != null ? this.period.hashCode() : 0;
            return result;
        }
    }
}
